Class: Google::Cloud::Dialogflow::V2::BatchDeleteEntityTypesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb

Overview

The request message for EntityTypes::BatchDeleteEntityTypes.

Instance Attribute Summary collapse

Instance Attribute Details

#entity_type_names ⇒ Array<String>

Returns Required. The names entity types to delete. All names must point to the same agent as parent.

Returns:

  • (Array<String>) —

    Required. The names entity types to delete. All names must point to the same agent as parent.



214
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 214

class BatchDeleteEntityTypesRequest; end

#parent ⇒ String

Returns Required. The name of the agent to delete all entities types for. Format: projects/<Project ID>/agent.

Returns:

  • (String) —

    Required. The name of the agent to delete all entities types for. Format: projects/<Project ID>/agent.



214
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 214

class BatchDeleteEntityTypesRequest; end