Class: Google::Cloud::Dialogflow::V2::BatchUpdateEntityTypesRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb

Overview

The request message for EntityTypes::BatchUpdateEntityTypes.

Instance Attribute Summary collapse

Instance Attribute Details

#entity_type_batch_inline ⇒ Google::Cloud::Dialogflow::V2::EntityTypeBatch

Returns The collection of entity type to update or create.

Returns:



197
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 197

class BatchUpdateEntityTypesRequest; end

#entity_type_batch_uri ⇒ String

Returns The URI to a Google Cloud Storage file containing entity types to update or create. The file format can either be a serialized proto (of EntityBatch type) or a JSON object. Note: The URI must start with "gs://".

Returns:

  • (String) —

    The URI to a Google Cloud Storage file containing entity types to update or create. The file format can either be a serialized proto (of EntityBatch type) or a JSON object. Note: The URI must start with "gs://".



197
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 197

class BatchUpdateEntityTypesRequest; end

#language_code ⇒ String

Returns Optional. The language of entity synonyms defined in entity_types. If not specified, the agent's default language is used. More than a dozen languages are supported. Note: languages must be enabled in the agent, before they can be used.

Returns:

  • (String) —

    Optional. The language of entity synonyms defined in entity_types. If not specified, the agent's default language is used. More than a dozen languages are supported. Note: languages must be enabled in the agent, before they can be used.



197
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 197

class BatchUpdateEntityTypesRequest; end

#parent ⇒ String

Returns Required. The name of the agent to update or create entity types in. Format: projects/<Project ID>/agent.

Returns:

  • (String) —

    Required. The name of the agent to update or create entity types in. Format: projects/<Project ID>/agent.



197
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 197

class BatchUpdateEntityTypesRequest; end

#update_mask ⇒ Google::Protobuf::FieldMask

Returns Optional. The mask to control which fields get updated.

Returns:



197
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/entity_type.rb', line 197

class BatchUpdateEntityTypesRequest; end