Class: Google::Cloud::Dialogflow::V2::Intent::Message::SimpleResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb

Overview

The simple response message containing speech or text.

Instance Attribute Summary collapse

Instance Attribute Details

#display_text ⇒ String

Returns Optional. The text to display.

Returns:

  • (String) —

    Optional. The text to display.



300
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 300

class SimpleResponse; end

#ssml ⇒ String

Returns One of text_to_speech or ssml must be provided. Structured spoken response to the user in the SSML format. Mutually exclusive with text_to_speech.

Returns:

  • (String) —

    One of text_to_speech or ssml must be provided. Structured spoken response to the user in the SSML format. Mutually exclusive with text_to_speech.



300
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 300

class SimpleResponse; end

#text_to_speech ⇒ String

Returns One of text_to_speech or ssml must be provided. The plain text of the speech output. Mutually exclusive with ssml.

Returns:

  • (String) —

    One of text_to_speech or ssml must be provided. The plain text of the speech output. Mutually exclusive with ssml.



300
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 300

class SimpleResponse; end