Class: Google::Cloud::Dialogflow::V2::Intent::Parameter

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb

Overview

Represents intent parameters.

Instance Attribute Summary collapse

Instance Attribute Details

#default_value ⇒ String

Returns Optional. The default value to use when the value yields an empty result. Default values can be extracted from contexts by using the following syntax: #context_name.parameter_name.

Returns:

  • (String) —

    Optional. The default value to use when the value yields an empty result. Default values can be extracted from contexts by using the following syntax: #context_name.parameter_name.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#display_name ⇒ String

Returns Required. The name of the parameter.

Returns:

  • (String) —

    Required. The name of the parameter.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#entity_type_display_name ⇒ String

Returns Optional. The name of the entity type, prefixed with @, that describes values of the parameter. If the parameter is required, this must be provided.

Returns:

  • (String) —

    Optional. The name of the entity type, prefixed with @, that describes values of the parameter. If the parameter is required, this must be provided.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#is_list ⇒ true, false

Returns Optional. Indicates whether the parameter represents a list of values.

Returns:

  • (true, false) —

    Optional. Indicates whether the parameter represents a list of values.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#mandatory ⇒ true, false

Returns Optional. Indicates whether the parameter is required. That is, whether the intent cannot be completed without collecting the parameter value.

Returns:

  • (true, false) —

    Optional. Indicates whether the parameter is required. That is, whether the intent cannot be completed without collecting the parameter value.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#name ⇒ String

Returns The unique identifier of this parameter.

Returns:

  • (String) —

    The unique identifier of this parameter.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#prompts ⇒ Array<String>

Returns Optional. The collection of prompts that the agent can present to the user in order to collect value for the parameter.

Returns:

  • (Array<String>) —

    Optional. The collection of prompts that the agent can present to the user in order to collect value for the parameter.



195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end

#value ⇒ String

Returns Optional. The definition of the parameter value. It can be:

  • a constant string,
  • a parameter value defined as $parameter_name,
  • an original parameter value defined as $parameter_name.original,
  • a parameter value from some context defined as #context_name.parameter_name.

Returns:

  • (String) —

    Optional. The definition of the parameter value. It can be:

    • a constant string,
    • a parameter value defined as $parameter_name,
    • an original parameter value defined as $parameter_name.original,
    • a parameter value from some context defined as #context_name.parameter_name.


195
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/intent.rb', line 195

class Parameter; end