Class: Google::Cloud::Dialogflow::V2::RestoreAgentRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/agent.rb

Overview

The request message for Agents::RestoreAgent.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_content ⇒ String

Returns The agent to restore.

Example for how to restore an agent via the command line:

curl
'https://dialogflow.googleapis.com/v2/projects/<project_name>/agent:restore
-X POST
-H 'Authorization: Bearer '$(gcloud auth print-access-token)
-H 'Accept: application/json'
-H 'Content-Type: application/json'
--compressed
--data-binary "{ 'agentContent': '$(cat | base64 -w 0)' }" .

Returns:

  • (String) —

    The agent to restore.

    Example for how to restore an agent via the command line:

    curl
    'https://dialogflow.googleapis.com/v2/projects/<project_name>/agent:restore
    -X POST
    -H 'Authorization: Bearer '$(gcloud auth print-access-token)
    -H 'Accept: application/json'
    -H 'Content-Type: application/json'
    --compressed
    --data-binary "{ 'agentContent': '$(cat | base64 -w 0)' }" \



209
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/agent.rb', line 209

class RestoreAgentRequest; end

#agent_uri ⇒ String

Returns The URI to a Google Cloud Storage file containing the agent to restore. Note: The URI must start with "gs://".

Returns:

  • (String) —

    The URI to a Google Cloud Storage file containing the agent to restore. Note: The URI must start with "gs://".



209
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/agent.rb', line 209

class RestoreAgentRequest; end

#parent ⇒ String

Returns Required. The project that the agent to restore is associated with. Format: projects/<Project ID>.

Returns:

  • (String) —

    Required. The project that the agent to restore is associated with. Format: projects/<Project ID>.



209
# File 'lib/google/cloud/dialogflow/v2/doc/google/cloud/dialogflow/v2/agent.rb', line 209

class RestoreAgentRequest; end